@@ -84,7 +84,7 @@
 #define SOLID_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SOLID_NO_DEPRECATED
-#  define SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57000
 #endif
 #ifdef SOLID_NO_DEPRECATED_WARNINGS
 #  define SOLID_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SOLID_DEPRECATED_WARNINGS_SINCE SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SOLID_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define SOLID_DEPRECATED_WARNINGS_SINCE 0x57000
 #  endif
 #endif
 
